# PulpOstreeClient::RepositoriesOstreeApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](RepositoriesOstreeApi.md#create) | **POST** /pulp/api/v3/repositories/ostree/ostree/ | Create an ostree repository
[**delete**](RepositoriesOstreeApi.md#delete) | **DELETE** {ostree_ostree_repository_href} | Delete an ostree repository
[**import_all**](RepositoriesOstreeApi.md#import_all) | **POST** {ostree_ostree_repository_href}import_all/ | Import refs and commits to a repository
[**import_commits**](RepositoriesOstreeApi.md#import_commits) | **POST** {ostree_ostree_repository_href}import_commits/ | Append child commits to a repository
[**list**](RepositoriesOstreeApi.md#list) | **GET** /pulp/api/v3/repositories/ostree/ostree/ | List ostree repositorys
[**modify**](RepositoriesOstreeApi.md#modify) | **POST** {ostree_ostree_repository_href}modify/ | Modify repository
[**partial_update**](RepositoriesOstreeApi.md#partial_update) | **PATCH** {ostree_ostree_repository_href} | Update an ostree repository
[**read**](RepositoriesOstreeApi.md#read) | **GET** {ostree_ostree_repository_href} | Inspect an ostree repository
[**sync**](RepositoriesOstreeApi.md#sync) | **POST** {ostree_ostree_repository_href}sync/ | Sync from remote
[**update**](RepositoriesOstreeApi.md#update) | **PUT** {ostree_ostree_repository_href} | Update an ostree repository



## create

> OstreeOstreeRepositoryResponse create(ostree_ostree_repository)

Create an ostree repository

A ViewSet class for OSTree repositories.

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RepositoriesOstreeApi.new
ostree_ostree_repository = PulpOstreeClient::OstreeOstreeRepository.new # OstreeOstreeRepository | 

begin
  #Create an ostree repository
  result = api_instance.create(ostree_ostree_repository)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RepositoriesOstreeApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_repository** | [**OstreeOstreeRepository**](OstreeOstreeRepository.md)|  | 

### Return type

[**OstreeOstreeRepositoryResponse**](OstreeOstreeRepositoryResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(ostree_ostree_repository_href)

Delete an ostree repository

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RepositoriesOstreeApi.new
ostree_ostree_repository_href = 'ostree_ostree_repository_href_example' # String | 

begin
  #Delete an ostree repository
  result = api_instance.delete(ostree_ostree_repository_href)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RepositoriesOstreeApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_repository_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## import_all

> AsyncOperationResponse import_all(ostree_ostree_repository_href, ostree_import_all)

Import refs and commits to a repository

Trigger an asynchronous task to import all refs and commits to a repository.

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RepositoriesOstreeApi.new
ostree_ostree_repository_href = 'ostree_ostree_repository_href_example' # String | 
ostree_import_all = PulpOstreeClient::OstreeImportAll.new # OstreeImportAll | 

begin
  #Import refs and commits to a repository
  result = api_instance.import_all(ostree_ostree_repository_href, ostree_import_all)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RepositoriesOstreeApi->import_all: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_repository_href** | **String**|  | 
 **ostree_import_all** | [**OstreeImportAll**](OstreeImportAll.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## import_commits

> AsyncOperationResponse import_commits(ostree_ostree_repository_href, ostree_import_commits_to_ref)

Append child commits to a repository

Trigger an asynchronous task to append child commits to a repository.

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RepositoriesOstreeApi.new
ostree_ostree_repository_href = 'ostree_ostree_repository_href_example' # String | 
ostree_import_commits_to_ref = PulpOstreeClient::OstreeImportCommitsToRef.new # OstreeImportCommitsToRef | 

begin
  #Append child commits to a repository
  result = api_instance.import_commits(ostree_ostree_repository_href, ostree_import_commits_to_ref)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RepositoriesOstreeApi->import_commits: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_repository_href** | **String**|  | 
 **ostree_import_commits_to_ref** | [**OstreeImportCommitsToRef**](OstreeImportCommitsToRef.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## list

> PaginatedostreeOstreeRepositoryResponseList list(opts)

List ostree repositorys

A ViewSet class for OSTree repositories.

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RepositoriesOstreeApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | Filter results where name matches value
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  remote: 'remote_example', # String | Foreign Key referenced by HREF
  retain_repo_versions: 56, # Integer | Filter results where retain_repo_versions matches value
  retain_repo_versions__gt: 56, # Integer | Filter results where retain_repo_versions is greater than value
  retain_repo_versions__gte: 56, # Integer | Filter results where retain_repo_versions is greater than or equal to value
  retain_repo_versions__isnull: true, # Boolean | Filter results where retain_repo_versions has a null value
  retain_repo_versions__lt: 56, # Integer | Filter results where retain_repo_versions is less than value
  retain_repo_versions__lte: 56, # Integer | Filter results where retain_repo_versions is less than or equal to value
  retain_repo_versions__ne: 56, # Integer | Filter results where retain_repo_versions not equal to value
  retain_repo_versions__range: [56], # Array<Integer> | Filter results where retain_repo_versions is between two comma separated values
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List ostree repositorys
  result = api_instance.list(opts)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RepositoriesOstreeApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| Filter results where name matches value | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **remote** | **String**| Foreign Key referenced by HREF | [optional] 
 **retain_repo_versions** | **Integer**| Filter results where retain_repo_versions matches value | [optional] 
 **retain_repo_versions__gt** | **Integer**| Filter results where retain_repo_versions is greater than value | [optional] 
 **retain_repo_versions__gte** | **Integer**| Filter results where retain_repo_versions is greater than or equal to value | [optional] 
 **retain_repo_versions__isnull** | **Boolean**| Filter results where retain_repo_versions has a null value | [optional] 
 **retain_repo_versions__lt** | **Integer**| Filter results where retain_repo_versions is less than value | [optional] 
 **retain_repo_versions__lte** | **Integer**| Filter results where retain_repo_versions is less than or equal to value | [optional] 
 **retain_repo_versions__ne** | **Integer**| Filter results where retain_repo_versions not equal to value | [optional] 
 **retain_repo_versions__range** | [**Array&lt;Integer&gt;**](Integer.md)| Filter results where retain_repo_versions is between two comma separated values | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedostreeOstreeRepositoryResponseList**](PaginatedostreeOstreeRepositoryResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## modify

> AsyncOperationResponse modify(ostree_ostree_repository_href, repository_add_remove_content)

Modify repository

Trigger an asynchronous task to modify content.

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RepositoriesOstreeApi.new
ostree_ostree_repository_href = 'ostree_ostree_repository_href_example' # String | 
repository_add_remove_content = PulpOstreeClient::RepositoryAddRemoveContent.new # RepositoryAddRemoveContent | 

begin
  #Modify repository
  result = api_instance.modify(ostree_ostree_repository_href, repository_add_remove_content)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RepositoriesOstreeApi->modify: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_repository_href** | **String**|  | 
 **repository_add_remove_content** | [**RepositoryAddRemoveContent**](RepositoryAddRemoveContent.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(ostree_ostree_repository_href, patchedostree_ostree_repository)

Update an ostree repository

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RepositoriesOstreeApi.new
ostree_ostree_repository_href = 'ostree_ostree_repository_href_example' # String | 
patchedostree_ostree_repository = PulpOstreeClient::PatchedostreeOstreeRepository.new # PatchedostreeOstreeRepository | 

begin
  #Update an ostree repository
  result = api_instance.partial_update(ostree_ostree_repository_href, patchedostree_ostree_repository)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RepositoriesOstreeApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_repository_href** | **String**|  | 
 **patchedostree_ostree_repository** | [**PatchedostreeOstreeRepository**](PatchedostreeOstreeRepository.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> OstreeOstreeRepositoryResponse read(ostree_ostree_repository_href, opts)

Inspect an ostree repository

A ViewSet class for OSTree repositories.

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RepositoriesOstreeApi.new
ostree_ostree_repository_href = 'ostree_ostree_repository_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect an ostree repository
  result = api_instance.read(ostree_ostree_repository_href, opts)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RepositoriesOstreeApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_repository_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**OstreeOstreeRepositoryResponse**](OstreeOstreeRepositoryResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## sync

> AsyncOperationResponse sync(ostree_ostree_repository_href, repository_sync_url)

Sync from remote

Trigger an asynchronous task to sync content.

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RepositoriesOstreeApi.new
ostree_ostree_repository_href = 'ostree_ostree_repository_href_example' # String | 
repository_sync_url = PulpOstreeClient::RepositorySyncURL.new # RepositorySyncURL | 

begin
  #Sync from remote
  result = api_instance.sync(ostree_ostree_repository_href, repository_sync_url)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RepositoriesOstreeApi->sync: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_repository_href** | **String**|  | 
 **repository_sync_url** | [**RepositorySyncURL**](RepositorySyncURL.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## update

> AsyncOperationResponse update(ostree_ostree_repository_href, ostree_ostree_repository)

Update an ostree repository

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_ostree_client'
# setup authorization
PulpOstreeClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpOstreeClient::RepositoriesOstreeApi.new
ostree_ostree_repository_href = 'ostree_ostree_repository_href_example' # String | 
ostree_ostree_repository = PulpOstreeClient::OstreeOstreeRepository.new # OstreeOstreeRepository | 

begin
  #Update an ostree repository
  result = api_instance.update(ostree_ostree_repository_href, ostree_ostree_repository)
  p result
rescue PulpOstreeClient::ApiError => e
  puts "Exception when calling RepositoriesOstreeApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ostree_ostree_repository_href** | **String**|  | 
 **ostree_ostree_repository** | [**OstreeOstreeRepository**](OstreeOstreeRepository.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

